gaawr2: Genetic Association Analysis

gaawr2R Documentation

Genetic Association Analysis

Description

This is a companion to Henry-Stewart talk by Zhao (2026, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.69645/FRFQ9519")}), which gathers information, metadata and scripts to showcase modern genetic analysis – ranging from testing of polymorphic variant(s) for Hardy-Weinberg equilibrium, association with traits using genetic and statistical models, Bayesian implementation, power calculation in study design, and genetic annotation. It also covers R integration with the Linux environment, GitHub, package creation and web applications. The earlier version by Zhao (2009, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.69645/DCRY5578")}) provides a brief introduction to these topics.

Details

Available data and function are listed in the following table.

Objects Description
Dataset  
DiaHealth A Bangladeshi dataset for Type 2 diabetes prediction
diabetes A diabetes dataset
Functions  
welcome An enhanced welcome

We can add references such as \insertCiteRpack:bibtex;textualRdpack.

Usage

Vignettes on package usage:

  • Genetic Association Analysis with R (II), vignette("gaawr2").

  • Web facilities, vignette("web").

Author(s)

Jing Hua Zhao in collaboration with other colleagues.

References

\insertAllCited

See Also

Useful links:

Examples

welcome(3)

gaawr2 documentation built on March 10, 2026, 5:08 p.m.